gatenlp.impl API documentation
Description: This subpackage contains modules for (temporary) implementation of datastructures and algorithms needed. Some of these may get replaced by other …

# Module `gatenlp.impl`

This subpackage contains modules for (temporary) implementation of datastructures and algorithms needed. Some of these may get replaced by other libraries or by better implementations in a separate packate.

Expand source code

    """
    This subpackage contains modules for (temporary) implementation of
    datastructures and algorithms needed. Some of these may get replaced
    by other libraries or by better implementations in a separate packate.
    """

    from gatenlp.impl.sortedintvls import SortedIntvls

## Sub-modules

`gatenlp.impl.sortedintvls`

  Module that provides a simple class that represents a collection of sorted intervals and allows for some basic interval-based operations …